@@ -4,13 +4,9 @@
 <!--BEGIN STABILITY BANNER-->---
 
 
-![cdk-constructs: Experimental](https://img.shields.io/badge/cdk--constructs-experimental-important.svg?style=for-the-badge)
+![cdk-constructs: Stable](https://img.shields.io/badge/cdk--constructs-stable-success.svg?style=for-the-badge)
 
 ---
-
-
-> This library is currently under development. Do not use!
-
 <!--END STABILITY BANNER-->
 
 This module exports a single class called `KubectlLayer` which is a `lambda.LayerVersion` that
